@@ -140,6 +140,7 @@ class TestCreatePort(TestPort):
             '--binding-profile', 'foo=bar',
             '--binding-profile', 'foo2=bar2',
             '--network', self._port.network_id,
+            '--dns-name', '8.8.8.8',
             'test-port',
 
         ]
@@ -156,6 +157,7 @@ class TestCreatePort(TestPort):
             ('vnic_type', 'macvtap'),
             ('binding_profile', {'foo': 'bar', 'foo2': 'bar2'}),
             ('network', self._port.network_id),
+            ('dns_name', '8.8.8.8'),
             ('name', 'test-port'),
 
         ]
@@ -174,6 +176,7 @@ class TestCreatePort(TestPort):
             'binding:vnic_type': 'macvtap',
             'binding:profile': {'foo': 'bar', 'foo2': 'bar2'},
             'network_id': self._port.network_id,
+            'dns_name': '8.8.8.8',
             'name': 'test-port',
         })
 
@@ -241,6 +244,7 @@ class TestCreatePort(TestPort):
             '--security-group', secgroup.id,
             'test-port',
         ]
+
         verifylist = [
             ('network', self._port.network_id,),
             ('enable', True),
@@ -262,6 +266,33 @@ class TestCreatePort(TestPort):
         self.assertEqual(ref_columns, columns)
         self.assertEqual(ref_data, data)
 
+    def test_create_port_with_dns_name(self):
+        arglist = [
+            '--network', self._port.network_id,
+            '--dns-name', '8.8.8.8',
+            'test-port',
+        ]
+        verifylist = [
+            ('network', self._port.network_id,),
+            ('enable', True),
+            ('dns_name', '8.8.8.8'),
+            ('name', 'test-port'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        self.network.create_port.assert_called_once_with(**{
+            'admin_state_up': True,
+            'network_id': self._port.network_id,
+            'dns_name': '8.8.8.8',
+            'name': 'test-port',
+        })
+
+        ref_columns, ref_data = self._get_common_cols_data(self._port)
+        self.assertEqual(ref_columns, columns)
+        self.assertEqual(ref_data, data)
+
     def test_create_with_security_groups(self):
         sg_1 = network_fakes.FakeSecurityGroup.create_one_security_group()
         sg_2 = network_fakes.FakeSecurityGroup.create_one_security_group()
@@ -293,7 +324,7 @@ class TestCreatePort(TestPort):
         self.assertEqual(ref_columns, columns)
         self.assertEqual(ref_data, data)
 
-    def test_create_with_no_secuirty_groups(self):
+    def test_create_with_no_security_groups(self):
         arglist = [
             '--network', self._port.network_id,
             '--no-security-group',
@@ -320,6 +351,54 @@ class TestCreatePort(TestPort):
         self.assertEqual(ref_columns, columns)
         self.assertEqual(ref_data, data)
 
+    def test_create_port_security_enabled(self):
+        arglist = [
+            '--network', self._port.network_id,
+            '--enable-port-security',
+            'test-port',
+        ]
+        verifylist = [
+            ('network', self._port.network_id,),
+            ('enable', True),
+            ('enable_port_security', True),
+            ('name', 'test-port'),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.network.create_port.assert_called_once_with(**{
+            'admin_state_up': True,
+            'network_id': self._port.network_id,
+            'port_security_enabled': True,
+            'name': 'test-port',
+        })
+
+    def test_create_port_security_disabled(self):
+        arglist = [
+            '--network', self._port.network_id,
+            '--disable-port-security',
+            'test-port',
+        ]
+        verifylist = [
+            ('network', self._port.network_id,),
+            ('enable', True),
+            ('disable_port_security', True),
+            ('name', 'test-port'),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.network.create_port.assert_called_once_with(**{
+            'admin_state_up': True,
+            'network_id': self._port.network_id,
+            'port_security_enabled': False,
+            'name': 'test-port',
+        })
+
 
 class TestDeletePort(TestPort):
 
@@ -628,6 +707,25 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
+    def test_set_dns_name(self):
+        arglist = [
+            '--dns-name', '8.8.8.8',
+            self._port.name,
+        ]
+        verifylist = [
+            ('dns_name', '8.8.8.8'),
+            ('port', self._port.name),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        result = self.cmd.take_action(parsed_args)
+
+        attrs = {
+            'dns_name': '8.8.8.8',
+        }
+        self.network.update_port.assert_called_once_with(self._port, **attrs)
+        self.assertIsNone(result)
+
     def test_append_fixed_ip(self):
         _testport = network_fakes.FakePort.create_one_port(
             {'fixed_ips': [{'ip_address': '0.0.0.1'}]})
@@ -898,6 +996,42 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(_testport, **attrs)
         self.assertIsNone(result)
 
+    def test_port_security_enabled(self):
+        arglist = [
+            '--enable-port-security',
+            self._port.id,
+        ]
+        verifylist = [
+            ('enable_port_security', True),
+            ('port', self._port.id,)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.network.update_port.assert_called_once_with(self._port, **{
+            'port_security_enabled': True,
+        })
+
+    def test_port_security_disabled(self):
+        arglist = [
+            '--disable-port-security',
+            self._port.id,
+        ]
+        verifylist = [
+            ('disable_port_security', True),
+            ('port', self._port.id,)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.network.update_port.assert_called_once_with(self._port, **{
+            'port_security_enabled': False,
+        })
+
 
 class TestShowPort(TestPort):
 
